.. Pyoda Time documentation master file, created by
   sphinx-quickstart on Sat Feb 24 21:09:00 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

A better date and time API for Python
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   API<pyoda_time>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
